pecos.circuits.hyqc.cops
========================

.. automodule:: pecos.circuits.hyqc.cops











   .. rubric:: Classes

   .. autosummary::

      AND
      BinOp
      COp
      CompOp
      EQUIV
      GE
      GT
      LE
      LT
      MINUS
      NEQUIV
      NOT
      OR
      PLUS
      UnaryOp
      XOR
